@@ -32,6 +32,8 @@ public interface VpcOffering extends InternalIdentity, Identity {
     public static final String redundantVPCOfferingName = "Redundant VPC offering";
     public static final String DEFAULT_VPC_NAT_NSX_OFFERING_NAME = "VPC offering with NSX - NAT Mode";
     public static final String DEFAULT_VPC_ROUTE_NSX_OFFERING_NAME = "VPC offering with NSX - Route Mode";
+    public static final String DEFAULT_VPC_ROUTE_NETRIS_OFFERING_NAME = "VPC offering with Netris - Route Mode";
+    public static final String DEFAULT_VPC_NAT_NETRIS_OFFERING_NAME = "VPC offering with Netris - NAT Mode";
 
     /**
      *
@@ -56,8 +58,6 @@ public interface VpcOffering extends InternalIdentity, Identity {
      */
     boolean isDefault();
 
-    boolean isForNsx();
-
     NetworkOffering.NetworkMode getNetworkMode();
 
     /**
