@@ -19,6 +19,7 @@
 package com.cloud.server;
 
 import java.util.Date;
+import java.util.List;
 
 /**
  * management server related stats
@@ -70,6 +71,10 @@ public interface ManagementServerHostStats {
 
     String getOsDistribution();
 
+    List<String> getLastAgents();
+
+    List<String> getAgents();
+
     int getAgentCount();
 
     long getHeapMemoryUsed();
