@@ -145,10 +145,14 @@ public interface VirtualMachineTemplate extends ControlledEntity, Identity, Inte
 
     boolean isDeployAsIs();
 
+    boolean isForCks();
+
     Long getUserDataId();
 
     UserData.UserDataOverridePolicy getUserDataOverridePolicy();
 
     CPU.CPUArch getArch();
 
+    Long getExtensionId();
+
 }
