@@ -27,7 +27,6 @@ import org.apache.cloudstack.api.ServerApiException;
 import org.apache.cloudstack.api.response.PodResponse;
 import org.apache.cloudstack.api.response.SuccessResponse;
 import org.apache.cloudstack.api.response.ZoneResponse;
-import org.apache.log4j.Logger;
 
 import com.cloud.event.EventTypes;
 
@@ -35,7 +34,6 @@ import com.cloud.event.EventTypes;
         requestHasSensitiveInfo = false, responseHasSensitiveInfo = false)
 public class GenerateAlertCmd extends BaseAsyncCmd {
 
-    public static final Logger s_logger = Logger.getLogger(GenerateAlertCmd.class.getName());
 
 
     // ///////////////////////////////////////////////////
