@@ -17,6 +17,7 @@
 
 package org.apache.cloudstack.api.command.admin.autoscale;
 
+import org.apache.cloudstack.context.CallContext;
 
 import org.apache.cloudstack.api.APICommand;
 import org.apache.cloudstack.api.ApiCommandResourceType;
@@ -89,9 +90,6 @@ public class CreateCounterCmd extends BaseAsyncCreateCmd {
         if (ctr != null) {
             this.setEntityId(ctr.getId());
             this.setEntityUuid(ctr.getUuid());
-            CounterResponse response = _responseGenerator.createCounterResponse(ctr);
-            response.setResponseName(getCommandName());
-            this.setResponseObject(response);
         } else {
             throw new ServerApiException(ApiErrorCode.INTERNAL_ERROR, "Failed to create Counter with name " + getName());
         }
@@ -99,6 +97,11 @@ public class CreateCounterCmd extends BaseAsyncCreateCmd {
 
     @Override
     public void execute() {
+        CallContext.current().setEventDetails("Counter ID: " + getEntityId());
+        Counter ctr = _autoScaleService.getCounter(getEntityId());
+        CounterResponse response = _responseGenerator.createCounterResponse(ctr);
+        response.setResponseName(getCommandName());
+        this.setResponseObject(response);
     }
 
     @Override
