@@ -17,7 +17,6 @@
 package org.apache.cloudstack.api.command.admin.guest;
 
 import org.apache.commons.lang3.BooleanUtils;
-import org.apache.log4j.Logger;
 
 import org.apache.cloudstack.api.APICommand;
 import org.apache.cloudstack.api.ApiCommandResourceType;
@@ -35,7 +34,6 @@ import com.cloud.user.Account;
 @APICommand(name = "updateGuestOsMapping", description = "Updates the information about Guest OS to Hypervisor specific name mapping", responseObject = GuestOsMappingResponse.class,
         since = "4.4.0", requestHasSensitiveInfo = false, responseHasSensitiveInfo = false)
 public class UpdateGuestOsMappingCmd extends BaseAsyncCmd {
-    public static final Logger s_logger = Logger.getLogger(UpdateGuestOsMappingCmd.class.getName());
 
 
     /////////////////////////////////////////////////////
