@@ -20,7 +20,6 @@ import java.util.Map;
 
 import javax.inject.Inject;
 
-import org.apache.log4j.Logger;
 
 import org.apache.cloudstack.api.APICommand;
 import org.apache.cloudstack.api.ApiConstants;
@@ -44,7 +43,6 @@ import com.cloud.utils.exception.CloudRuntimeException;
             responseObject = NetworkDeviceResponse.class,
             requestHasSensitiveInfo = false, responseHasSensitiveInfo = false)
 public class AddNetworkDeviceCmd extends BaseCmd {
-    public static final Logger s_logger = Logger.getLogger(AddNetworkDeviceCmd.class);
 
     // ///////////////////////////////////////////////////
     // ////////////// API parameters /////////////////////
