@@ -17,7 +17,6 @@
 
 package org.apache.cloudstack.api.command.admin.region;
 
-import org.apache.log4j.Logger;
 
 import org.apache.cloudstack.api.APICommand;
 import org.apache.cloudstack.api.ApiCommandResourceType;
@@ -35,7 +34,6 @@ import com.cloud.user.Account;
 @APICommand(name = "deletePortableIpRange", description = "deletes a range of portable public IP's associated with a region", responseObject = SuccessResponse.class,
         requestHasSensitiveInfo = false, responseHasSensitiveInfo = false)
 public class DeletePortableIpRangeCmd extends BaseAsyncCmd {
-    public static final Logger s_logger = Logger.getLogger(DeletePortableIpRangeCmd.class.getName());
 
     private static final String s_name = "deleteportablepublicipresponse";
 
