@@ -31,6 +31,8 @@ import org.apache.cloudstack.context.CallContext;
 import com.cloud.dc.DataCenter;
 import com.cloud.user.Account;
 
+import java.util.List;
+
 @APICommand(name = "createZone", description = "Creates a Zone.", responseObject = ZoneResponse.class,
         requestHasSensitiveInfo = false, responseHasSensitiveInfo = false)
 public class CreateZoneCmd extends BaseCmd {
@@ -88,6 +90,11 @@ public class CreateZoneCmd extends BaseCmd {
     @Parameter(name = ApiConstants.IS_EDGE, type = CommandType.BOOLEAN, description = "true if the zone is an edge zone, false otherwise", since = "4.18.0")
     private Boolean isEdge;
 
+    @Parameter(name = ApiConstants.STORAGE_ACCESS_GROUPS,
+            type = CommandType.LIST, collectionType = CommandType.STRING,
+            description = "comma separated list of storage access groups for the hosts in the zone",
+            since = "4.21.0")
+    private List<String> storageAccessGroups;
 
     /////////////////////////////////////////////////////
     /////////////////// Accessors ///////////////////////
@@ -162,6 +169,10 @@ public class CreateZoneCmd extends BaseCmd {
         return isEdge;
     }
 
+    public List<String> getStorageAccessGroups() {
+        return storageAccessGroups;
+    }
+
     /////////////////////////////////////////////////////
     /////////////// API Implementation///////////////////
     @Override
