@@ -18,7 +18,6 @@ package org.apache.cloudstack.api.command.user.autoscale;
 
 import java.util.List;
 
-import org.apache.log4j.Logger;
 
 import org.apache.cloudstack.acl.RoleType;
 import org.apache.cloudstack.api.APICommand;
@@ -45,7 +44,6 @@ import com.cloud.network.rules.LoadBalancer;
             requestHasSensitiveInfo = false,
             responseHasSensitiveInfo = false)
 public class CreateAutoScaleVmGroupCmd extends BaseAsyncCreateCmd {
-    public static final Logger s_logger = Logger.getLogger(CreateAutoScaleVmGroupCmd.class.getName());
 
     private static final String s_name = "autoscalevmgroupresponse";
 
@@ -233,7 +231,7 @@ public class CreateAutoScaleVmGroupCmd extends BaseAsyncCreateCmd {
             }
         } catch (Exception ex) {
             // TODO what will happen if Resource Layer fails in a step in between
-            s_logger.warn("Failed to create autoscale vm group", ex);
+            logger.warn("Failed to create autoscale vm group", ex);
         } finally {
             if (!success || vmGroup == null) {
                 _autoScaleService.deleteAutoScaleVmGroup(getEntityId(), true);
