@@ -26,7 +26,9 @@ import org.apache.cloudstack.api.BaseListCmd;
 import org.apache.cloudstack.api.Parameter;
 import org.apache.cloudstack.api.response.GuestOSCategoryResponse;
 import org.apache.cloudstack.api.response.ListResponse;
+import org.apache.cloudstack.api.response.ZoneResponse;
 
+import com.cloud.cpu.CPU;
 import com.cloud.storage.GuestOsCategory;
 import com.cloud.utils.Pair;
 
@@ -39,12 +41,48 @@ public class ListGuestOsCategoriesCmd extends BaseListCmd {
     //////////////// API parameters /////////////////////
     /////////////////////////////////////////////////////
 
-    @Parameter(name = ApiConstants.ID, type = CommandType.UUID, entityType = GuestOSCategoryResponse.class, description = "list Os category by id")
+    @Parameter(name = ApiConstants.ID, type = CommandType.UUID, entityType = GuestOSCategoryResponse.class, description = "List OS category by id")
     private Long id;
 
-    @Parameter(name = ApiConstants.NAME, type = CommandType.STRING, description = "list os category by name", since = "3.0.1")
+    @Parameter(name = ApiConstants.NAME, type = CommandType.STRING, description = "List OS category by name", since = "3.0.1")
     private String name;
 
+    @Parameter(name = ApiConstants.IS_FEATURED,
+            type = CommandType.BOOLEAN,
+            description = "List available OS categories by featured or not",
+            since = "4.21.0")
+    private Boolean featured;
+
+    @Parameter(name = ApiConstants.IS_ISO,
+            type = CommandType.BOOLEAN,
+            description = "List OS categories for which an ISO is available",
+            since = "4.21.0")
+    private Boolean iso;
+
+    @Parameter(name = ApiConstants.IS_VNF, type = CommandType.BOOLEAN,
+            description = "List OS categories for which a VNF template is available",
+            since = "4.21.0")
+    private Boolean vnf;
+
+    @Parameter(name = ApiConstants.ZONE_ID,
+            type = CommandType.UUID,
+            entityType = ZoneResponse.class,
+            description = "List available OS categories types for the zone",
+            since = "4.21.0")
+    private Long zoneId;
+
+    @Parameter(name = ApiConstants.ARCH,
+            type = CommandType.STRING,
+            description = "List OS categories types available for given CPU architecture",
+            since = "4.21.0")
+    private String arch;
+
+    @Parameter(name = ApiConstants.SHOW_RESOURCE_ICON,
+            type = CommandType.BOOLEAN,
+            description = "flag to display the resource image for the OS category",
+            since = "4.21.0")
+    private Boolean showIcon;
+
     /////////////////////////////////////////////////////
     /////////////////// Accessors ///////////////////////
     /////////////////////////////////////////////////////
@@ -57,6 +95,30 @@ public class ListGuestOsCategoriesCmd extends BaseListCmd {
         return name;
     }
 
+    public Boolean isFeatured() {
+        return featured;
+    }
+
+    public Boolean isIso() {
+        return iso;
+    }
+
+    public Boolean isVnf() {
+        return vnf;
+    }
+
+    public Long getZoneId() {
+        return zoneId;
+    }
+
+    public CPU.CPUArch getArch() {
+        return arch == null ? null : CPU.CPUArch.fromType(arch);
+    }
+
+    public boolean isShowIcon() {
+        return Boolean.TRUE.equals(showIcon);
+    }
+
     /////////////////////////////////////////////////////
     /////////////// API Implementation///////////////////
     /////////////////////////////////////////////////////
@@ -64,14 +126,11 @@ public class ListGuestOsCategoriesCmd extends BaseListCmd {
     @Override
     public void execute() {
         Pair<List<? extends GuestOsCategory>, Integer> result = _mgr.listGuestOSCategoriesByCriteria(this);
-        ListResponse<GuestOSCategoryResponse> response = new ListResponse<GuestOSCategoryResponse>();
-        List<GuestOSCategoryResponse> osCatResponses = new ArrayList<GuestOSCategoryResponse>();
+        ListResponse<GuestOSCategoryResponse> response = new ListResponse<>();
+        List<GuestOSCategoryResponse> osCatResponses = new ArrayList<>();
         for (GuestOsCategory osCategory : result.first()) {
-            GuestOSCategoryResponse categoryResponse = new GuestOSCategoryResponse();
-            categoryResponse.setId(osCategory.getUuid());
-            categoryResponse.setName(osCategory.getName());
-
-            categoryResponse.setObjectName("oscategory");
+            GuestOSCategoryResponse categoryResponse = _responseGenerator.createGuestOSCategoryResponse(osCategory,
+                    isShowIcon());
             osCatResponses.add(categoryResponse);
         }
 
