@@ -18,7 +18,6 @@ package org.apache.cloudstack.api.command.user.loadbalancer;
 
 import javax.inject.Inject;
 
-import org.apache.log4j.Logger;
 
 import org.apache.cloudstack.api.APICommand;
 import org.apache.cloudstack.api.ApiConstants;
@@ -41,7 +40,6 @@ import org.apache.cloudstack.network.tls.CertService;
 @APICommand(name = "uploadSslCert", description = "Upload a certificate to CloudStack", responseObject = SslCertResponse.class,
         requestHasSensitiveInfo = false, responseHasSensitiveInfo = false)
 public class UploadSslCertCmd extends BaseCmd {
-    public static final Logger s_logger = Logger.getLogger(UploadSslCertCmd.class.getName());
 
 
     @Inject
