@@ -209,4 +209,9 @@ public class CreateSnapshotFromVMSnapshotCmd extends BaseAsyncCreateCmd {
         }
         return null;
     }
+
+    @Override
+    public Long getApiResourceId() {
+        return getEntityId();
+    }
 }
